@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.28  Copyright Tobias Oetiker, 1997 - 2000
+ * RRDtool 1.0.33  Copyright Tobias Oetiker, 1997 - 2000
  *****************************************************************************
  * rrd_dump  Display a RRD
  *****************************************************************************
@@ -123,7 +123,7 @@ rrd_dump(int argc, char **argv)
 #else
 # error "Need strftime"
 #endif
-	    printf("\t\t\t<!-- %s --> <row>",somestring);
+	    printf("\t\t\t<!-- %s / %d --> <row>",somestring,(int)now);
 	    for(iii=0;iii<rrd.stat_head->ds_cnt;iii++){			 
 		fread(&my_cdp,sizeof(rrd_value_t),1,in_file);		
 		if (isnan(my_cdp)){
