@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.28  Copyright Tobias Oetiker, 1997 - 2000
+ * RRDtool 1.0.33  Copyright Tobias Oetiker, 1997 - 2000
  *****************************************************************************
  * rrd_open.c  Open an RRD File
  *****************************************************************************
@@ -35,7 +35,7 @@ rrd_open(char *file_name, FILE **in_file, rrd_t *rrd, int rdwr)
     }
     
     if (((*in_file) = fopen(file_name,mode)) == NULL ){
-	rrd_set_error("rrdopen can't open '%s': %s",file_name, strerror(errno));
+	rrd_set_error("opening '%s': %s",file_name, strerror(errno));
 	return (-1);
     }
     
@@ -108,7 +108,7 @@ int readfile(char *file_name, char **buffer, int skipfirst){
     if ((strcmp("-",file_name) == 0)) { input = stdin; }
     else {
       if ((input = fopen(file_name,"rb")) == NULL ){
-	rrd_set_error("readfile can't open '%s': %s",file_name,strerror(errno));
+	rrd_set_error("opening '%s': %s",file_name,strerror(errno));
 	return (-1);
       }
     }
