@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.28  Copyright Tobias Oetiker, 1997 - 2000
+ * RRDtool 1.0.33  Copyright Tobias Oetiker, 1997 - 2001
  *****************************************************************************
  * rrd_tool.c  Startup wrapper
  *****************************************************************************/
@@ -17,8 +17,9 @@ int HandleInputLine(int, char **, FILE*);
 
 void PrintUsage(char *cmd)
 {
+
     char help_main[] =
-	   "RRDtool 1.0.28  Copyright 1997-2000 by Tobias Oetiker <tobi@oetiker.ch>\n\n"
+	   "RRDtool 1.0.33  Copyright 1997-2001 by Tobias Oetiker <tobi@oetiker.ch>\n\n"
 	   "Usage: rrdtool [options] command command_options\n\n";
 
     char help_list[] =
@@ -72,6 +73,8 @@ void PrintUsage(char *cmd)
 	   "\t\t[-l|--lower-limit value] [-r|--rigid]\n"
 	   "\t\t[--alt-autoscale]\n"
 	   "\t\t[--alt-autoscale-max]\n"
+	   "\t\t[--units-exponent value]\n"	   
+	   "\t\t[--step seconds]\n"	   
 	   "\t\t[-f|--imginfo printfstr]\n"
 	   "\t\t[-a|--imgformat GIF|PNG]\n"
 	   "\t\t[-c|--color COLORTAG#rrggbb] [-t|--title string]\n"
@@ -300,7 +303,7 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	     strcmp("v", argv[1]) == 0 ||
 	     strcmp("-v", argv[1]) == 0  ||
 	     strcmp("-version", argv[1]) == 0  )
-        printf("RRDtool 1.0.28  Copyright (C) 1997-2000 by Tobias Oetiker <tobi@oetiker.ch>\n");
+        printf("RRDtool 1.0.33  Copyright (C) 1997-2001 by Tobias Oetiker <tobi@oetiker.ch>\n");
     else if (strcmp("restore", argv[1]) == 0)
 	rrd_restore(argc-1, &argv[1]);
     else if (strcmp("resize", argv[1]) == 0)
