@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.28  Copyright Tobias Oetiker, 1997 - 2000
+ * RRDtool 1.0.33  Copyright Tobias Oetiker, 1997 - 2000
  *****************************************************************************
  * rrd_update.c  RRD Update Function
  *****************************************************************************
@@ -23,7 +23,27 @@ int LockRRD(FILE *rrd_file);
 
 /*#define DEBUG */
 
+
+#ifdef STANDALONE
 int 
+main(int argc, char **argv){
+        rrd_update(argc,argv);
+        if (rrd_test_error()) {
+                printf("RRDtool 1.0.33  Copyright 1997-2000 by Tobias Oetiker <tobi@oetiker.ch>\n\n"
+                        "Usage: rrdupdate filename\n"
+                        "\t\t\t[--template|-t ds-name:ds-name:...]\n"
+                        "\t\t\ttime|N:value[:value...]\n\n"
+                        "\t\t\t[ time:value[:value...] ..]\n\n");
+                                   
+                printf("ERROR: %s\n",rrd_get_error());
+                rrd_clear_error();                                                            
+                return 1;
+        }
+        return 0;
+}
+#endif
+
+int
 rrd_update(int argc, char **argv)
 {
 
@@ -102,7 +122,7 @@ rrd_update(int argc, char **argv)
 
     /* need at least 2 arguments: filename, data. */
     if (argc-optind < 2) {
-	rrd_set_error("not enough arguments");
+	rrd_set_error("Not enough arguments");
 	return -1;
     }
 
